==> node-mitmproxy-3.0.2.tgz: package/lib/mitmproxy/createRequestHandler.js <==
'use strict';

function _asyncToGenerator(fn) { return function () { var gen = fn.apply(this, arguments); return new Promise(function (resolve, reject) { function step(key, arg) { try { var info = gen[key](arg); var value = info.value; } catch (error) { reject(error); return; } if (info.done) { resolve(value); } else { return Promise.resolve(value).then(function (value) { return step("next", value); }, function (err) { return step("throw", err); }); } } return step("next"); }); }; }

var http = require('http');
var https = require('https');
var url = require('url');
var commonUtil = require('../common/util');
var upgradeHeader = /(^|,)\s*upgrade\s*($|,)/i;
var Agent = require('agentkeepalive');
var HttpsAgent = require('agentkeepalive').HttpsAgent;

var agent = new Agent();
var httpsAgent = new HttpsAgent();

// create requestHandler function
module.exports = function createRequestHandler(requestInterceptor, responseInterceptor, plugins) {

    // return
    return function requestHandler(req, res, ssl) {
        var _this = this;

        var proxyReq;

        var rOptions = commonUtil.getOptionsFormRequest(req, ssl);

        var requestInterceptorPromise = new Promise(function (resolve, reject) {
            var next = function next() {
                resolve();
            };
            try {
                if (typeof requestInterceptor === 'function') {
                    requestInterceptor.call(null, rOptions, req, res, ssl, next);
                } else {
                    resolve();
                }
            } catch (e) {
                reject(e);
            }
        });

        var proxyRequestPromise = new Promise(function (resolve, reject) {

            // keepAlive
            if (rOptions.headers.connection === 'keep-alive') {
                if (rOptions.protocol == 'https:') {
                    rOptions.agent = httpsAgent;
                } else {
                    rOptions.agent = agent;
                }
            }
            // copy from node-http-proxy :)
            // Remark: If we are false and not upgrading, set the connection: close. This is the right thing to do
            // as node core doesn't handle this COMPLETELY properly yet.
            //
            if (!rOptions.agent) {
                rOptions.headers = rOptions.headers || {};
                if (typeof rOptions.headers.connection !== 'string' || !upgradeHeader.test(rOptions.headers.connection)) {
                    rOptions.headers.connection = 'close';
                }
            }

            proxyReq = (rOptions.protocol == 'https:' ? https : http).request(rOptions, function (proxyRes) {
                resolve(proxyRes);
            });

            proxyReq.on('error', function (e) {
                console.log(e);
            });

            req.on('aborted', function () {
                proxyReq.abort();
            });
            req.pipe(proxyReq);
        });

        // workflow control
        _asyncToGenerator(regeneratorRuntime.mark(function _callee() {
            var proxyRes, responseInterceptorPromise;
            return regeneratorRuntime.wrap(function _callee$(_context) {
                while (1) {
                    switch (_context.prev = _context.next) {
                        case 0:
                            _context.next = 2;
                            return requestInterceptorPromise;

                        case 2:
                            if (!res.finished) {
                                _context.next = 4;
                                break;
                            }

                            return _context.abrupt('return', false);

                        case 4:
                            _context.next = 6;
                            return proxyRequestPromise;

                        case 6:
                            proxyRes = _context.sent;
                            responseInterceptorPromise = new Promise(function (resolve, reject) {
                                var next = function next() {
                                    resolve();
                                };
                                try {
                                    if (typeof responseInterceptor === 'function') {
                                        responseInterceptor.call(null, req, res, proxyReq, proxyRes, ssl, next);
                                    } else {
                                        resolve();
                                    }
                                } catch (e) {
                                    reject(e);
                                }
                            });
                            _context.next = 10;
                            return responseInterceptorPromise;

                        case 10:
                            if (!res.finished) {
                                _context.next = 12;
                                break;
                            }

                            return _context.abrupt('return', false);

                        case 12:

                            try {
                                // prevent duplicate set headers
                                if (!res.headersSent) {
                                    Object.keys(proxyRes.headers).forEach(function (key) {
                                        if (proxyRes.headers[key] != undefined) {
                                            var newkey = key.replace(/^[a-z]|-[a-z]/g, function (match) {
                                                return match.toUpperCase();
                                            });
                                            var newkey = key;
                                            res.setHeader(newkey, proxyRes.headers[key]);
                                        }
                                    });
                                    res.writeHead(proxyRes.statusCode);
                                    proxyRes.pipe(res);
                                }
                            } catch (e) {
                                console.error(e);
                            }

                        case 13:
                        case 'end':
                            return _context.stop();
                    }
                }
            }, _callee, _this);
        }))().then(function (flag) {
            // do nothing
        }, function (e) {
            console.error(e.stack);
        });
    };
};

==> node-mitmproxy-3.0.3.tgz: package/lib/mitmproxy/createRequestHandler.js <==
'use strict';

function _asyncToGenerator(fn) { return function () { var gen = fn.apply(this, arguments); return new Promise(function (resolve, reject) { function step(key, arg) { try { var info = gen[key](arg); var value = info.value; } catch (error) { reject(error); return; } if (info.done) { resolve(value); } else { return Promise.resolve(value).then(function (value) { return step("next", value); }, function (err) { return step("throw", err); }); } } return step("next"); }); }; }

var http = require('http');
var https = require('https');
var url = require('url');
var commonUtil = require('../common/util');
var upgradeHeader = /(^|,)\s*upgrade\s*($|,)/i;

// create requestHandler function
module.exports = function createRequestHandler(requestInterceptor, responseInterceptor, plugins) {

    // return
    return function requestHandler(req, res, ssl) {
        var _this = this;

        var proxyReq;

        var rOptions = commonUtil.getOptionsFormRequest(req, ssl);

        if (typeof rOptions.headers.connection === 'string' && rOptions.headers.connection === 'close') {
            req.socket.setKeepAlive(false);
            console.log('req.socket.setKeepAlive(false);');
        }

        var requestInterceptorPromise = new Promise(function (resolve, reject) {
            var next = function next() {
                resolve();
            };
            try {
                if (typeof requestInterceptor === 'function') {
                    requestInterceptor.call(null, rOptions, req, res, ssl, next);
                } else {
                    resolve();
                }
            } catch (e) {
                reject(e);
            }
        });

        var proxyRequestPromise = new Promise(function (resolve, reject) {

            proxyReq = (rOptions.protocol == 'https:' ? https : http).request(rOptions, function (proxyRes) {
                resolve(proxyRes);
            });

            proxyReq.on('error', function (e) {
                console.log(e);
            });

            req.on('aborted', function () {
                proxyReq.abort();
            });
            req.pipe(proxyReq);
        });

        // workflow control
        _asyncToGenerator(regeneratorRuntime.mark(function _callee() {
            var proxyRes, responseInterceptorPromise;
            return regeneratorRuntime.wrap(function _callee$(_context) {
                while (1) {
                    switch (_context.prev = _context.next) {
                        case 0:
                            _context.next = 2;
                            return requestInterceptorPromise;

                        case 2:
                            if (!res.finished) {
                                _context.next = 4;
                                break;
                            }

                            return _context.abrupt('return', false);

                        case 4:
                            _context.next = 6;
                            return proxyRequestPromise;

                        case 6:
                            proxyRes = _context.sent;
                            responseInterceptorPromise = new Promise(function (resolve, reject) {
                                var next = function next() {
                                    resolve();
                                };
                                try {
                                    if (typeof responseInterceptor === 'function') {
                                        responseInterceptor.call(null, req, res, proxyReq, proxyRes, ssl, next);
                                    } else {
                                        resolve();
                                    }
                                } catch (e) {
                                    reject(e);
                                }
                            });
                            _context.next = 10;
                            return responseInterceptorPromise;

                        case 10:
                            if (!res.finished) {
                                _context.next = 12;
                                break;
                            }

                            return _context.abrupt('return', false);

                        case 12:

                            try {

                                if (!res.headersSent) {
                                    // prevent duplicate set headers
                                    Object.keys(proxyRes.headers).forEach(function (key) {
                                        if (proxyRes.headers[key] != undefined) {
                                            // var key = key.replace(/^[a-z]|-[a-z]/g, (match) => {
                                            //     return match.toUpperCase()
                                            // });
                                            // https://github.com/nodejitsu/node-http-proxy/issues/362
                                            if (/^www-authenticate$/i.test(key)) {
                                                if (proxyRes.headers[key]) {
                                                    proxyRes.headers[key] = proxyRes.headers[key] && proxyRes.headers[key].split(',');
                                                }
                                                key = 'www-authenticate';
                                            }
                                            res.setHeader(key, proxyRes.headers[key]);
                                        }
                                    });
                                    res.writeHead(proxyRes.statusCode);
                                    proxyRes.pipe(res);
                                }
                            } catch (e) {
                                console.error(e);
                            }

                        case 13:
                        case 'end':
                            return _context.stop();
                    }
                }
            }, _callee, _this);
        }))().then(function (flag) {
            // do nothing
        }, function (e) {
            console.error(e.stack);
        });
    };
};
